@@ -199,7 +199,8 @@ def get_synchronization_tasks(object_name):
               'foreach': 'update.cl_update_other_rep_name',
               'message': __("Syncing the {eachvar:capitalize} repository"),
               'method': Object('syncOtherRepository(eachvar)'),
-              'condition': lambda GetBool: GetBool('update.cl_update_other_set')
+              'condition': lambda GetBool: (GetBool('update.cl_update_other_set') or
+                                            not GetBool('update.cl_update_other_git_exists'))
              },
              {'name': 'trim_reps',
               'foreach': 'update.cl_update_sync_rep',
